summaryrefslogtreecommitdiff
path: root/cmd/srv9p/main.c
diff options
context:
space:
mode:
Diffstat (limited to 'cmd/srv9p/main.c')
-rw-r--r--cmd/srv9p/main.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/cmd/srv9p/main.c b/cmd/srv9p/main.c
index d30c4f9..c5a3367 100644
--- a/cmd/srv9p/main.c
+++ b/cmd/srv9p/main.c
@@ -19,8 +19,8 @@
#include "config.h"
#ifndef CONFIG_NETIO_NUM_CONNS
#error config.h must define CONFIG_NETIO_NUM_CONNS
#endif
/* implementation *************************************************************/
@@ -104,10 +104,10 @@ int main() {
.rootdir = get_root,
};
- for (int i = 0; i < CONFIG_NETIO_NUM_CONNS; i++)
+ for (int i = 0; i < CONFIG_SRV9P_NUM_CONNS; i++)
if (!coroutine_add(read_cr, &srv))
error(1, 0, "coroutine_add(read_cr, &srv)");
- for (int i = 0; i < 2*CONFIG_NETIO_NUM_CONNS; i++)
+ for (int i = 0; i < 2*CONFIG_SRV9P_NUM_CONNS; i++)
if (!coroutine_add(lib9p_srv_write_cr, &srv))
error(1, 0, "coroutine_add(lib9p_srv_write_cr, &srv)");
@@ -19,8 +19,8 @@
#include "config.h"
-#ifndef CONFIG_NETIO_NUM_CONNS
- #error config.h must define CONFIG_NETIO_NUM_CONNS
+#ifndef CONFIG_SRV9P_NUM_CONNS
+ #error config.h must define CONFIG_SRV9P_NUM_CONNS
#endif
/* implementation *************************************************************/